@@ -292,17 +292,17 @@ func TestFileSystem_SwitchToShadowHandler(t *testing.T) {
 		Model: &model.Node{},
 	}
 
-	// remote to local
-	{
-		fs.Policy.Type = "remote"
-		fs.SwitchToShadowHandler(mockNode, "", "")
-		a.IsType(&masterinslave.Driver{}, fs.Handler)
-	}
-
 	// local to remote
 	{
 		fs.Policy.Type = "local"
 		fs.SwitchToShadowHandler(mockNode, "", "")
 		a.IsType(&masterinslave.Driver{}, fs.Handler)
 	}
+
+	// onedrive
+	{
+		fs.Policy.Type = "onedrive"
+		fs.SwitchToShadowHandler(mockNode, "", "")
+		a.IsType(&masterinslave.Driver{}, fs.Handler)
+	}
 }
